#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
test_urler
----------------------------------

Tests for `urler` module.
"""

import urler
import unittest
import mock


class TestUrler(unittest.TestCase):

    @mock.patch('__builtin__.open', create=True)
    def test_load_csv_file(self, mock_open):
        mock_open.side_effect = [
            mock.mock_open(read_data='localhost,8080,test1').return_value,
            mock.mock_open(read_data='localhost,8080,test2').return_value,
            mock.mock_open(read_data='localhost,8080,test2').return_value,
        ]
        self.assertEqual('localhost,8080,test1', urler.load_csv_file("file1.csv")[0])
        mock_open.assert_called_once_with('file1.csv', 'r')
        mock_open.reset_mock()

        self.assertEqual('localhost,8080,test2', urler.load_csv_file("file2.csv")[0])
        mock_open.assert_called_once_with('file2.csv', 'r')
        mock_open.reset_mock()

        with self.assertRaises(IndexError):
            urler.load_csv_file('file3.csv')[1]

        # could be done with a `with` statement
        self.assertRaises(SystemExit, lambda: urler.load_csv_file('file4.csv')[0])

    def test_create_target(self):
        csv = 'localhost,8080,test'
        target = 'localhost:8080/test'
        self.assertEqual(target, urler.create_target(csv))

if __name__ == '__main__':
    import sys
    sys.exit(unittest.main())



#!/usr/bin/env python
# -*- coding: utf-8 -*-

'''URLer
Usage:
    urler (<host> <port> <path> | <file>)
    urler (-h | --help | --version)

Examples:
    urler example.com 8080 index.html
    urler targets.csv

Assumptions:
    you know what you are doing

Commands:
    host         target host
    port         destination port
    path         URL path
    file         system path to a csv file with the following fields: host,port,path

Options:
    -h, --help    show this help message and exit
    --version     prints program version and exit
'''

from urllib3 import Timeout
from docopt import docopt
import urllib3
import sys


def load_csv_file(csv_file):
    ''' loads csv '''
    try:
        with open(csv_file, 'r') as f:
            return f.readlines()
    except Exception as e:
        sys.exit('urler: fatal - {0}'.format(e))


def create_target(csv_line):
    ''' converts a csv line to a url '''
    try:
        target = csv_line.split(',')
        return (target[0] + ':' + target[1] + "/" + target[2]).rstrip()
    except Exception as e:
        sys.exit('urler: fatal - {0}'.format(e))


def get_csv_url(list):
    ''' HTTP GET multiple urls '''
    try:
        return [(create_target(line), get_url(create_target(line))) for line in list]
    except Exception as e:
        sys.exit('urler: fatal - {0}'.format(e))


def get_url(url):
    ''' HTTP GET a single url '''
    try:
        http = urllib3.PoolManager()
        return (http.request('GET', url, timeout=Timeout(connect=1.0, read=1.0))).data
    except Exception as e:
        # don't stop when a single target fails
        print 'urler: fail - {0}'.format(e)
        return '<error>'


def main():
    ''' main entry point for the script '''
    arguments = docopt(__doc__, version='urler 0.1.1')
    host = arguments['<host>']
    port = arguments['<port>']
    path = arguments['<path>']
    filepath = arguments['<file>']

    if filepath:
        list = load_csv_file(filepath)
        print "\n".join((item[0] + ":\t" + item[1]) for item in get_csv_url(list))
    else:
        url = '{0}:{1}/{2}'.format(host, port, path)
        print get_url(url)

if __name__ == '__main__':
    sys.exit(main())



#!/usr/bin/env python
# -*- coding: utf-8 -*-


try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

# try:
#    import pypandoc
#    long_description = pypandoc.convert('README.md', 'rst')
# except(IOError, ImportError):
#     long_description = open('README.md').read()

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
    'docopt>=0.6.2',
    'urllib3>=1.9.1',
    'wsgiref>=0.1.2'
]

test_requirements = [
    'mock>=2.0.0'
]

setup(
    name='urler',
    version='0.1.1',
    description="URLer - GET it?",
    long_description=readme + '\n\n' + history,
    author="Joel Bastos",
    author_email='kintoandar@gmail.com',
    url='https://github.com/kintoandar/urler',
    packages=[
        'urler',
    ],
    package_dir={'urler':
                 'urler'},
    include_package_data=True,
    install_requires=requirements,
    license="MIT",
    zip_safe=False,
    keywords='urler',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: System Administrators',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
    entry_points = {
        'console_scripts': ['urler=urler.urler:main'],
    },
    test_suite='tests',
    tests_require=test_requirements
)
